@@ -50,11 +50,6 @@
 #include <pk11pqg.h>
 #include <base64.h>
 
-/* NSS - for password hashing */
-#include <pk11func.h>
-#include <pk11pqg.h>
-#include <base64.h>
-
 #include "libadminutil/resource.h"
 #include "libadminutil/admutil.h"
 #include "libadminutil/distadm.h"
@@ -73,11 +68,10 @@ sha1_pw_enc(const char *pwd)
    unsigned char hash[SHA1_LENGTH];
    char *enc;
    char *retval;
-   SECStatus rc;
    int32 pwdlen = strlen(pwd);
 
    /* SHA1 hash the user's key */
-   rc = PK11_HashBuf(SEC_OID_SHA1, hash, (unsigned char *)pwd, pwdlen);
+   PK11_HashBuf(SEC_OID_SHA1, hash, (unsigned char *)pwd, pwdlen);
    /* convert to base64 */
    if (!(enc = BTOA_DataToAscii(hash, sizeof(hash)))) {
       return NULL;
@@ -181,6 +175,7 @@ int main(int argc, char *argv[])
     int errorcode = 0;
     char *configdir = util_get_conf_dir();
 	    
+    (void)_ai; /* get rid of unused variable warning */
     logMsg(" In %s\n", argv[0]);
 
     i18nInit();
