@@ -155,9 +155,8 @@ int main(int argc, char *argv[])
   char           **inputs = 0;
   char           *operation = 0;
   char           *qs = 0;
-  char           *nameptr, *valptr, *val;
+  char           *nameptr, *valptr;
   char           error_info[128];
-  char           *valsbuf[2];
   int            setFlag = 0, getFlag = 0, forceSetFlag = 0;
   int            ignorePsetErrors = 0;
   AttributeList  resultList, nvl;
@@ -176,11 +175,9 @@ int main(int argc, char *argv[])
   while (waitforever);
 #endif
 
+  (void)_ai; /* get rid of unused variable warning */
   i18nResource = res_find_and_init_resource(PROPERTYDIR, RESOURCE_FILE);
 
-  valsbuf[0] = NULL;
-  valsbuf[1] = NULL;
-
   memset((void *)errp, 0, sizeof(int));
   method = getenv("REQUEST_METHOD");
 
@@ -620,7 +617,7 @@ int main(int argc, char *argv[])
 #endif
 
 	errorCode = PSET_OP_OK;
-	val = psetGetAttrSingleValue(pset, nameptr, &errorCode);
+	(void)psetGetAttrSingleValue(pset, nameptr, &errorCode);
 	if (errorCode && !ignorePsetErrors) {
 	  if (forceSetFlag) 
 	    addSingleValueAttribute(addList, j++, nameptr, valptr);
@@ -717,7 +714,7 @@ static char * read_conf(char *file, char *name) {
   f = fopen(filename, "r");
   if (f==NULL) {
     char msg[BIG_LINE];
-    PR_snprintf(msg, BIG_LINE, "Cannot open file %s for reading", filename);
+    PR_snprintf(msg, BIG_LINE, "Cannot open file %s/%s for reading", configdir, file);
     rpt_err(SYSTEM_ERROR, msg, NULL, NULL);
   }
 
@@ -755,7 +752,7 @@ static int update_conf(char *file, char *name, char *val) {
   f = fopen(filename, "r");
   if (f==NULL) {
     char msg[BIG_LINE];
-    PR_snprintf(msg, BIG_LINE, "Cannot open file %s for reading", filename);
+    PR_snprintf(msg, BIG_LINE, "Cannot open file %s/%s for reading", configdir, file);
     rpt_err(SYSTEM_ERROR, msg, NULL, NULL);
   }
 
